@@ -163,17 +163,17 @@ gssdp_client_init (GSSDPClient *client)
 }
 
 static void
-gssdp_client_initable_iface_init (gpointer g_iface,
-                                  gpointer iface_data)
+gssdp_client_initable_iface_init (gpointer               g_iface,
+                                  G_GNUC_UNUSED gpointer iface_data)
 {
         GInitableIface *iface = (GInitableIface *)g_iface;
         iface->init = gssdp_client_initable_init;
 }
 
 static gboolean
-gssdp_client_initable_init (GInitable     *initable,
-                            GCancellable  *cancellable,
-                            GError       **error)
+gssdp_client_initable_init (GInitable                   *initable,
+                            G_GNUC_UNUSED GCancellable  *cancellable,
+                            GError                     **error)
 {
         GSSDPClient *client = GSSDP_CLIENT (initable);
         GError *internal_error = NULL;
@@ -1052,9 +1052,9 @@ out:
 }
 
 static gboolean
-request_socket_source_cb (GIOChannel  *source,
-                          GIOCondition condition,
-                          gpointer     user_data)
+request_socket_source_cb (G_GNUC_UNUSED GIOChannel  *source,
+                          G_GNUC_UNUSED GIOCondition condition,
+                          gpointer                   user_data)
 {
         GSSDPClient *client;
 
@@ -1064,9 +1064,9 @@ request_socket_source_cb (GIOChannel  *source,
 }
 
 static gboolean
-multicast_socket_source_cb (GIOChannel  *source,
-                            GIOCondition condition,
-                            gpointer     user_data)
+multicast_socket_source_cb (G_GNUC_UNUSED GIOChannel  *source,
+                            G_GNUC_UNUSED GIOCondition condition,
+                            gpointer                   user_data)
 {
         GSSDPClient *client;
 
@@ -1076,9 +1076,9 @@ multicast_socket_source_cb (GIOChannel  *source,
 }
 
 static gboolean
-search_socket_source_cb (GIOChannel  *source,
-                         GIOCondition condition,
-                         gpointer     user_data)
+search_socket_source_cb (G_GNUC_UNUSED GIOChannel  *source,
+                         G_GNUC_UNUSED GIOCondition condition,
+                         gpointer                   user_data)
 {
         GSSDPClient *client;
 
