@@ -913,7 +913,11 @@ check_target_compat (GSSDPResourceBrowser *resource_browser,
         g_free (tmp);
         g_match_info_free (info);
 
-        return version >= resource_browser->priv->version;
+        if (version < 0) {
+            return FALSE;
+        }
+
+        return (uint) version >= resource_browser->priv->version;
 }
 
 static void
@@ -964,12 +968,12 @@ received_announcement (GSSDPResourceBrowser *resource_browser,
  * Received a message
  */
 static void
-message_received_cb (GSSDPClient        *client,
-                     const char         *from_ip,
-                     gushort             from_port,
-                     _GSSDPMessageType   type,
-                     SoupMessageHeaders *headers,
-                     gpointer            user_data)
+message_received_cb (G_GNUC_UNUSED GSSDPClient *client,
+                     G_GNUC_UNUSED const char  *from_ip,
+                     G_GNUC_UNUSED gushort      from_port,
+                     _GSSDPMessageType          type,
+                     SoupMessageHeaders        *headers,
+                     gpointer                   user_data)
 {
         GSSDPResourceBrowser *resource_browser;
 
@@ -1008,7 +1012,9 @@ resource_free (gpointer data)
 }
 
 static gboolean
-clear_cache_helper (gpointer key, gpointer value, gpointer data)
+clear_cache_helper (G_GNUC_UNUSED gpointer key,
+                    gpointer               value,
+                    G_GNUC_UNUSED gpointer data)
 {
         Resource *resource;
 
